@@ -1,5 +1,6 @@
 import importlib
 from pathlib import Path
+from typing import Optional
 
 import typer
 
@@ -10,6 +11,14 @@ app.add_typer(solr_cli.solr_app, name="solr")
 app.add_typer(sql_cli.sql_app, name="sql")
 
 
+@app.callback(invoke_without_command=True)
+def callback(version: Optional[bool] = typer.Option(None, "--version", is_eager=True)):
+    if version:
+        from monarch_py import __version__
+        typer.echo(f"monarch_py version: {__version__}")
+        raise typer.Exit() 
+
+
 @app.command("schema")
 def schema():
     """
@@ -24,15 +33,23 @@ def schema():
         print(schema_file.read())
     raise typer.Exit()
 
+
 ### "Aliases" for Solr CLI ###
 
+
 @app.command("entity")
 def entity(
     id: str = typer.Argument(None, help="The identifier of the entity to be retrieved"),
-    update: bool = typer.Option(False, "--update", "-u", help="Whether to re-download the Monarch KG"),
-    fmt: str = typer.Option("json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"),
-    output: str = typer.Option(None, "--output", "-o", help="The path to the output file"),
-    ):
+    update: bool = typer.Option(
+        False, "--update", "-u", help="Whether to re-download the Monarch KG"
+    ),
+    fmt: str = typer.Option(
+        "json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"
+    ),
+    output: str = typer.Option(
+        None, "--output", "-o", help="The path to the output file"
+    ),
+):
     """
     Retrieve an entity by ID
 
@@ -55,8 +72,15 @@ def associations(
     between: str = typer.Option(None, "--between"),
     limit: int = typer.Option(20, "--limit", "-l"),
     offset: int = typer.Option(0, "--offset"),
-    fmt: str = typer.Option("json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"),
-    output: str = typer.Option(None, "--output", "-o", help="The path to the output file"),
+    update: bool = typer.Option(
+        False, "--update", "-u", help="Whether to re-download the Monarch KG"
+    ),
+    fmt: str = typer.Option(
+        "json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"
+    ),
+    output: str = typer.Option(
+        None, "--output", "-o", help="The path to the output file"
+    ),
 ):
     """
     Paginate through associations
@@ -82,8 +106,12 @@ def search(
     taxon: str = typer.Option(None, "--taxon"),
     limit: int = typer.Option(20, "--limit"),
     offset: int = typer.Option(0, "--offset"),
-    fmt: str = typer.Option("json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"),
-    output: str = typer.Option(None, "--output", "-o", help="The path to the output file"),
+    fmt: str = typer.Option(
+        "json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"
+    ),
+    output: str = typer.Option(
+        None, "--output", "-o", help="The path to the output file"
+    ),
 ):
     """
     Search for entities
@@ -100,12 +128,40 @@ def search(
     solr_cli.search(**locals())
 
 
+@app.command("autocomplete")
+def autocomplete(
+    q: str = typer.Argument(None, help="Query string to autocomplete against"),
+    fmt: str = typer.Option(
+        "json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"
+    ),
+    output: str = typer.Option(
+        None, "--output", "-o", help="The path to the output file"
+    ),
+):
+    """
+    Return entity autcomplete matches for a query string
+
+    Args:
+        q: The query string to autocomplete against
+        fmt: The format of the output (TSV, YAML, JSON)
+        output: The path to the output file (stdout if not specified)
+
+    """
+    solr_cli.autocomplete(**locals())
+
+
 @app.command("histopheno")
 def histopheno(
     subject: str = typer.Argument(None, help="The subject of the association"),
-    update: bool = typer.Option(False, "--update", "-u", help="Whether to re-download the Monarch KG"),
-    fmt: str = typer.Option("json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"),
-    output: str = typer.Option(None, "--output", "-o", help="The path to the output file")
+    update: bool = typer.Option(
+        False, "--update", "-u", help="Whether to re-download the Monarch KG"
+    ),
+    fmt: str = typer.Option(
+        "json", "--format", "-f", help="The format of the output (TSV, YAML, JSON)"
+    ),
+    output: str = typer.Option(
+        None, "--output", "-o", help="The path to the output file"
+    ),
 ):
     """
     Retrieve the histopheno data for an entity by ID
